==> haskell-blaze-markup-0.8.2.8-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-markup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 blaze-markup
version:              0.8.2.8
visibility:           public
id:                   blaze-markup-0.8.2.8-Fy7PnHGD1dJDHiW5frrF9S
key:                  blaze-markup-0.8.2.8-Fy7PnHGD1dJDHiW5frrF9S
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt, Simon Meier, Deepak Jois
stability:            Experimental
homepage:             http://jaspervdj.be/blaze
synopsis:             A blazingly fast markup combinator library for Haskell
description:
    Core modules of a blazingly fast markup combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.

category:             Text
abi:                  df17582cdc6c1823a9ea5f993bcc9304
exposed:              True
exposed-modules:
    Text.Blaze Text.Blaze.Internal Text.Blaze.Renderer.Pretty
    Text.Blaze.Renderer.String Text.Blaze.Renderer.Text
    Text.Blaze.Renderer.Utf8

import-dirs:          /usr/lib/ghc-9.0.2/site-local/blaze-markup-0.8.2.8
library-dirs:         /usr/lib/ghc-9.0.2/site-local/blaze-markup-0.8.2.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/blaze-markup-0.8.2.8
hs-libraries:         HSblaze-markup-0.8.2.8-Fy7PnHGD1dJDHiW5frrF9S
depends:
    base-4.15.1.0 blaze-builder-0.4.2.2-2gLNFpRfQ1I6uT3J9lURjU
    bytestring-0.10.12.1 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock

haddock-html:         /usr/share/doc/haskell-blaze-markup/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-markup-0.8.2.8-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-markup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 blaze-markup
version:              0.8.2.8
visibility:           public
id:                   blaze-markup-0.8.2.8-8VKDplVPPUXFFofdW2QyFc
key:                  blaze-markup-0.8.2.8-8VKDplVPPUXFFofdW2QyFc
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt, Simon Meier, Deepak Jois
stability:            Experimental
homepage:             http://jaspervdj.be/blaze
synopsis:             A blazingly fast markup combinator library for Haskell
description:
    Core modules of a blazingly fast markup combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.

category:             Text
abi:                  9d2f9b190d68f4f5d19aa1c4174fb97b
exposed:              True
exposed-modules:
    Text.Blaze Text.Blaze.Internal Text.Blaze.Renderer.Pretty
    Text.Blaze.Renderer.String Text.Blaze.Renderer.Text
    Text.Blaze.Renderer.Utf8

import-dirs:          /usr/lib/ghc-9.0.2/site-local/blaze-markup-0.8.2.8
library-dirs:         /usr/lib/ghc-9.0.2/site-local/blaze-markup-0.8.2.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/blaze-markup-0.8.2.8
hs-libraries:         HSblaze-markup-0.8.2.8-8VKDplVPPUXFFofdW2QyFc
depends:
    base-4.15.1.0 blaze-builder-0.4.2.2-2gLNFpRfQ1I6uT3J9lURjU
    bytestring-0.10.12.1 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock

haddock-html:         /usr/share/doc/haskell-blaze-markup/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
